@@ -2,7 +2,7 @@ use array_init::{array_init, try_array_init};
 use num_bigint::BigInt;
 use num_rational::BigRational;
 use num_traits::*;
-use ordered_float::{FloatIsNan, NotNan, OrderedFloat};
+use ordered_float::{FloatIsNan, NotNan};
 use rand::distributions::{Distribution, Standard};
 use rand::Rng;
 use std::cmp::Ordering;
@@ -264,138 +264,10 @@ mod sub;
 #[cfg(test)]
 pub mod tests {
   use super::*;
+  use crate::testing::*;
   use crate::Orientation::*;
 
-  use ordered_float::Float;
-  use ordered_float::NotNan;
-  use std::convert::TryInto;
-  use std::fmt::Debug;
-  use std::ops::IndexMut;
-
-  use proptest::array::*;
-  use proptest::collection::*;
-  use proptest::num;
   use proptest::prelude::*;
-  use proptest::strategy::*;
-  use proptest::test_runner::*;
-
-  pub struct PointValueTree<T, const N: usize> {
-    point: Point<T, N>,
-    shrink: usize,
-    prev_shrink: Option<usize>,
-  }
-  impl<T, const N: usize> ValueTree for PointValueTree<T, N>
-  where
-    T: ValueTree,
-  {
-    type Value = Point<<T as ValueTree>::Value, N>;
-    fn current(&self) -> Point<T::Value, N> {
-      Point {
-        array: array_init(|i| self.point.array.index(i).current()),
-      }
-    }
-    fn simplify(&mut self) -> bool {
-      for ix in self.shrink..N {
-        if !self.point.array.index_mut(ix).simplify() {
-          self.shrink = ix + 1;
-        } else {
-          self.prev_shrink = Some(ix);
-          return true;
-        }
-      }
-      false
-    }
-    fn complicate(&mut self) -> bool {
-      match self.prev_shrink {
-        None => false,
-        Some(ix) => {
-          if self.point.array.index_mut(ix).complicate() {
-            true
-          } else {
-            self.prev_shrink = None;
-            false
-          }
-        }
-      }
-    }
-  }
-
-  impl<T, const N: usize> Strategy for Point<T, N>
-  where
-    T: Clone + Debug + Strategy,
-  {
-    type Tree = PointValueTree<T::Tree, N>;
-    type Value = Point<<T as Strategy>::Value, N>;
-    fn new_tree(&self, runner: &mut TestRunner) -> NewTree<Self> {
-      let tree = PointValueTree {
-        point: Point {
-          array: try_array_init(|i| self.array.index(i).new_tree(runner))?,
-        },
-        shrink: 0,
-        prev_shrink: None,
-      };
-
-      Ok(tree)
-    }
-  }
-
-  impl<const N: usize> Arbitrary for Point<f64, N> {
-    type Strategy = Point<num::f64::Any, N>;
-    type Parameters = ();
-    fn arbitrary_with(_params: ()) -> Self::Strategy {
-      use num::f64::*;
-      let strat = POSITIVE | NEGATIVE | NORMAL | SUBNORMAL | ZERO;
-      Point {
-        array: array_init(|_| strat),
-      }
-    }
-  }
-
-  impl<const N: usize> Arbitrary for Point<isize, N> {
-    type Strategy = Point<num::isize::Any, N>;
-    type Parameters = ();
-    fn arbitrary_with(_params: ()) -> Self::Strategy {
-      Point {
-        array: array_init(|_| any::<isize>()),
-      }
-    }
-  }
-
-  impl<const N: usize> Arbitrary for Point<i64, N> {
-    type Strategy = Point<num::i64::Any, N>;
-    type Parameters = ();
-    fn arbitrary_with(_params: ()) -> Self::Strategy {
-      Point {
-        array: array_init(|_| any::<i64>()),
-      }
-    }
-  }
-
-  impl<const N: usize> Arbitrary for Point<i8, N> {
-    type Strategy = Point<num::i8::Any, N>;
-    type Parameters = ();
-    fn arbitrary_with(_params: ()) -> Self::Strategy {
-      Point {
-        array: array_init(|_| any::<i8>()),
-      }
-    }
-  }
-
-  pub fn any_nn<const N: usize>() -> impl Strategy<Value = Point<NotNan<f64>, N>> {
-    any::<Point<f64, N>>().prop_filter_map("Check for NaN", |pt| pt.try_into().ok())
-  }
-
-  pub fn any_r<const N: usize>() -> impl Strategy<Value = Point<BigInt, N>> {
-    any::<Point<isize, N>>().prop_map(|pt| pt.cast(BigInt::from))
-  }
-
-  pub fn any_64<const N: usize>() -> impl Strategy<Value = Point<i64, N>> {
-    any::<Point<i64, N>>()
-  }
-
-  pub fn any_8<const N: usize>() -> impl Strategy<Value = Point<i8, N>> {
-    any::<Point<i8, N>>()
-  }
 
   proptest! {
     #[test]
