@@ -2,14 +2,15 @@ use claim::debug_assert_ok;
 use num_bigint::BigInt;
 use num_rational::BigRational;
 use num_traits::*;
+use rand::distributions::uniform::SampleUniform;
 use rand::distributions::{Distribution, Standard};
 use rand::seq::SliceRandom;
 use rand::Rng;
+use rand::SeedableRng;
 use std::collections::BTreeSet;
 use std::ops::*;
 
 use crate::array::Orientation;
-use crate::data;
 use crate::data::Point;
 use crate::data::PointLocation;
 use crate::data::TriangleView;
@@ -60,7 +61,7 @@ where
     }
     let p1 = poly.point(vertices[lower]);
     let p2 = poly.point(vertices[upper]);
-    let triangle = TriangleView::new([p0, p1, p2]);
+    let triangle = TriangleView::new_unchecked([p0, p1, p2]);
     triangle.locate(pt)
   }
 
@@ -78,60 +79,62 @@ where
   pub fn polygon(&self) -> &Polygon<T> {
     self.into()
   }
+
+  pub fn normalize(&self) -> PolygonConvex<BigRational>
+  where
+    T: PolygonScalar + Into<BigInt>,
+    T::ExtendedSigned: Into<BigInt>,
+  {
+    PolygonConvex::new_unchecked(self.0.normalize())
+  }
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 // PolygonConvex<BigRational>
 
-impl PolygonConvex<BigRational> {
+impl<T> PolygonConvex<T>
+where
+  T: Bounded + PolygonScalar + SampleUniform + Copy + Into<BigInt>,
+{
   /// $O(n \log n)$ Uniformly sample a random convex polygon.
   ///
-  /// The output polygon is centered at (0,0), and has a maximum width and height of 2 units.
+  /// The output polygon is rooted in (0,0), grows upwards, and has a height and width of T::MAX.
   ///
   /// ```no_run
   /// # use rgeometry_wasm::playground::*;
   /// # use rgeometry::data::*;
-  /// # let convex = {
-  /// PolygonConvex::random(3, 1000, &mut rand::thread_rng())
+  /// # let convex: PolygonConvex<i8> = {
+  /// PolygonConvex::random(3, &mut rand::thread_rng())
   /// # };
-  /// # render_polygon(&convex);
+  /// # render_polygon(&convex.normalize());
   /// ```
   /// <iframe src="https://web.rgeometry.org:20443/loader.html?gist=037a23f8391390df8560a2043a14121e"></iframe>
-  pub fn random<R>(n: usize, max: usize, rng: &mut R) -> PolygonConvex<BigRational>
+  pub fn random<R>(n: usize, rng: &mut R) -> PolygonConvex<T>
   where
     R: Rng + ?Sized,
   {
-    if n < 3 {
-      // Return Result<P, Error> instead?
-      return PolygonConvex::random(3, max, rng);
-    }
+    let n = n.max(3);
     let vs = {
-      let mut vs = random_vectors(n, max, rng);
+      let mut vs = random_vectors(n, rng);
       Vector::sort_around(&mut vs);
       vs
     };
-    let vertices: Vec<Point<BigRational, 2>> = vs
+    let vertices: Vec<Point<T, 2>> = vs
       .into_iter()
       .scan(Point::zero(), |st, vec| {
         *st += vec;
-        Some(st.clone())
+        Some(*st)
       })
       .collect();
     let n_vertices = (*vertices).len();
     debug_assert_eq!(n_vertices, n);
-    let p = Polygon::new_unchecked(vertices);
-    for cursor in p.iter_boundary() {
-      if cursor.orientation() != Orientation::CounterClockWise {
-        return Self::random(n, max, rng);
-      }
+    // FIXME: Use the convex hull algorithm for polygons rather than point sets.
+    //        It runs in O(n) rather than O(n log n). Hasn't been implemented, yet, though.
+    match crate::algorithms::convex_hull(vertices).ok() {
+      // If the vertices are all colinear then give up and try again.
+      None => Self::random(n, rng),
+      Some(p) => p,
     }
-    let centroid = p.centroid();
-    let t = Transform::translate(-Vector::from(centroid));
-    let s = Transform::uniform_scale(BigRational::new(
-      One::one(),
-      BigInt::from_usize(max).unwrap(),
-    ));
-    PolygonConvex::new_unchecked(s * t * p)
   }
 }
 
@@ -157,9 +160,9 @@ impl<'a, T> From<&'a PolygonConvex<T>> for &'a Polygon<T> {
   }
 }
 
-impl Distribution<PolygonConvex<BigRational>> for Standard {
-  fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> PolygonConvex<BigRational> {
-    PolygonConvex::random(100, usize::MAX, rng)
+impl Distribution<PolygonConvex<isize>> for Standard {
+  fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> PolygonConvex<isize> {
+    PolygonConvex::random(100, rng)
   }
 }
 
@@ -167,76 +170,54 @@ impl Distribution<PolygonConvex<BigRational>> for Standard {
 // Helper functions
 
 // Property: random_between(n, max, &mut rng).sum::<usize>() == max
-fn random_between_iter<R>(n: usize, max: usize, rng: &mut R) -> impl Iterator<Item = usize>
+fn random_between_iter<T, R>(n: usize, rng: &mut R) -> impl Iterator<Item = T>
 where
+  T: PolygonScalar + Bounded + SampleUniform + Copy + Into<BigInt>,
   R: Rng + ?Sized,
 {
+  let zero: T = Zero::zero();
+  let max: T = Bounded::max_value();
   assert!(n > 0);
-  assert!(n <= max);
-  let mut pts = BTreeSet::new();
+  let mut pts = Vec::with_capacity(n);
   while pts.len() < n - 1 {
-    pts.insert(rng.gen_range(1..max));
+    pts.push(rng.gen_range(zero..max));
   }
-  pts.insert(max);
-  pts.into_iter().scan(0, |from, x| {
+  pts.sort_unstable();
+  pts.push(max);
+  pts.into_iter().scan(zero, |from, x| {
     let out = x - *from;
     *from = x;
     Some(out)
   })
 }
 
-// Property: random_between(n, max, &mut rng).iter().sum::<usize>() == max
-// fn random_between<R>(n: usize, max: usize, rng: &mut R) -> Vec<usize>
-// where
-//   R: Rng + ?Sized,
-// {
-//   assert!(n > 0);
-//   assert!(n <= max);
-//   if max == n {
-//     return vec![1; n];
-//   }
-//   let mut pts = BTreeSet::new();
-//   while pts.len() < n - 1 {
-//     pts.insert(rng.gen_range(1..max));
-//   }
-//   pts.insert(max);
-//   let mut from = 0;
-//   let mut out = Vec::new();
-//   for x in pts.iter() {
-//     out.push(x - from);
-//     from = *x;
-//   }
-//   out
-// }
-
 // Property: random_between_zero(10, 100, &mut rng).iter().sum::<isize>() == 0
-// Property: random_between_zero(10, 100, &mut rng).iter().all(|v| !v.is_zero())
-fn random_between_zero<R>(n: usize, max: usize, rng: &mut R) -> Vec<BigInt>
+fn random_between_zero<T, R>(n: usize, rng: &mut R) -> Vec<T>
 where
+  T: Bounded + PolygonScalar + SampleUniform + Copy + Into<BigInt>,
   R: Rng + ?Sized,
 {
   assert!(n >= 2);
   let n_positive = rng.gen_range(1..n); // [1;n[
   let n_negative = n - n_positive;
   assert!(n_positive + n_negative == n);
-  let positive = random_between_iter(n_positive, max, rng).map(BigInt::from);
-  let negative = random_between_iter(n_negative, max, rng)
-    .map(BigInt::from)
-    .map(Neg::neg);
-  let mut result: Vec<BigInt> = positive.chain(negative).collect();
+  let positive = random_between_iter(n_positive, rng);
+  let negative = random_between_iter(n_negative, rng).map(|i: T| -i);
+  let mut result: Vec<T> = positive.chain(negative).collect();
   result.shuffle(rng);
   result
 }
 
 // Random vectors that sum to zero.
-fn random_vectors<R>(n: usize, max: usize, rng: &mut R) -> Vec<Vector<BigRational, 2>>
+fn random_vectors<T, R>(n: usize, rng: &mut R) -> Vec<Vector<T, 2>>
 where
+  T: Bounded + PolygonScalar + SampleUniform + Copy + Into<BigInt>,
   R: Rng + ?Sized,
 {
-  random_between_zero(n, max, rng)
+  random_between_zero(n, rng)
     .into_iter()
-    .zip(random_between_zero(n, max, rng).into_iter())
-    .map(|(a, b)| Vector([BigRational::from(a), BigRational::from(b)]))
+    .zip(random_between_zero(n, rng).into_iter())
+    .map(|(a, b)| Vector([a, b]))
     .collect()
 }
 
@@ -246,60 +227,58 @@ where
 #[cfg(test)]
 mod tests {
   use super::*;
-  use crate::Orientation::*;
-  use crate::*;
 
+  use crate::testing::*;
   use proptest::prelude::*;
-  use proptest::strategy::*;
-  use proptest::test_runner::*;
-
-  use ordered_float::NotNan;
-
-  impl Arbitrary for PolygonConvex<BigRational> {
-    type Strategy = Just<PolygonConvex<BigRational>>;
-    type Parameters = ();
-    fn arbitrary_with(_params: ()) -> Self::Strategy {
-      Self::arbitrary()
-    }
-    fn arbitrary() -> Self::Strategy {
-      let mut rng = rand::thread_rng();
-      // let n = rng.gen_range(3..=20);
-      let n = 5;
-      let p = PolygonConvex::random(n, 1_000_000_000, &mut rng);
-      Just(p)
-    }
-  }
 
   proptest! {
-    // #[test]
-    // fn all_random_convex_polygons_are_valid(poly: PolygonConvex<BigRational>) {
-    //   prop_assert_eq!(poly.validate().err(), None)
-    // }
-
     #[test]
-    fn sum_to_max(n in 1..1000, max in 0..1_000_000) {
-      let mut rng = rand::thread_rng();
-      let max = std::cmp::max(max, n);
-      let vecs = random_between_iter(n as usize, max as usize, &mut rng);
-      prop_assert_eq!(vecs.sum::<usize>(), max as usize)
+    fn all_random_convex_polygons_are_valid_i8(poly in any_convex::<i8>()) {
+      prop_assert_eq!(poly.validate().err(), None)
     }
 
     #[test]
-    fn random_between_zero_properties(n in 2..1000, max in 0..1_000_000) {
+    fn random_convex_prop(poly in any_convex::<i8>()) {
+      let (min, max) = poly.bounding_box();
+      prop_assert_eq!(min.y_coord(), &0);
+      let width = max.x_coord() - min.x_coord();
+      let height = max.y_coord() - min.y_coord();
+      prop_assert_eq!(width, i8::MAX);
+      prop_assert_eq!(height, i8::MAX);
+    }
+
+    #[test]
+    fn all_random_convex_polygons_are_valid_i64(poly in any_convex::<i64>()) {
+      prop_assert_eq!(poly.validate().err(), None)
+    }
+
+    #[test]
+    fn sum_to_max(n in 1..1000) {
       let mut rng = rand::thread_rng();
-      let max = std::cmp::max(max, n);
-      let vecs = random_between_zero(n as usize, max as usize, &mut rng);
-      prop_assert_eq!(vecs.iter().sum::<BigInt>(), BigInt::from(0));
-      prop_assert!(vecs.iter().all(|v| !v.is_zero()));
+      let vecs = random_between_iter::<i8, _>(n as usize, &mut rng);
+      prop_assert_eq!(vecs.sum::<i8>(), i8::MAX);
+
+      let vecs = random_between_iter::<i64, _>(n as usize, &mut rng);
+      prop_assert_eq!(vecs.sum::<i64>(), i64::MAX);
+    }
+
+    #[test]
+    fn random_between_zero_properties(n in 2..1000) {
+      let mut rng = rand::thread_rng();
+      let vecs: Vec<i8> = random_between_zero(n as usize, &mut rng);
+      prop_assert_eq!(vecs.iter().sum::<i8>(), 0);
+      prop_assert_eq!(vecs.len(), n as usize);
+
+      let vecs: Vec<i64> = random_between_zero(n as usize, &mut rng);
+      prop_assert_eq!(vecs.iter().sum::<i64>(), 0);
       prop_assert_eq!(vecs.len(), n as usize);
     }
 
     #[test]
-    fn sum_to_zero_vector(n in 2..1000, max in 0..1_000_000) {
+    fn sum_to_zero_vector(n in 2..1000) {
       let mut rng = rand::thread_rng();
-      let max = std::cmp::max(max, n);
-      let vecs = random_vectors(n as usize, max as usize, &mut rng);
-      prop_assert_eq!(vecs.into_iter().sum::<Vector<BigRational,2>>(), Vector::zero())
+      let vecs: Vec<Vector<i8,2>> = random_vectors(n as usize, &mut rng);
+      prop_assert_eq!(vecs.into_iter().sum::<Vector<i8,2>>(), Vector::zero())
     }
   }
 }
